@@ -61,7 +61,6 @@
 #include <KWindowInfo>
 #include <KGlobal>
 #include <KCharsets>
-#include <KMessageBox>
 
 // Qt Includes
 #include <QVBoxLayout>
@@ -92,42 +91,49 @@ Application::~Application()
 
     Q_FOREACH(QWeakPointer<MainWindow> window, m_mainWindows)
     {
+        kDebug() << "deleting windows...";
         delete window.data();
         window.clear();
     }
 
     if (!m_historyManager.isNull())
     {
+        kDebug() << "deleting history manager";
         delete m_historyManager.data();
         m_historyManager.clear();
     }
 
     if (!m_bookmarkProvider.isNull())
     {
+        kDebug() << "deleting bookmark Provider";
         delete m_bookmarkProvider.data();
         m_bookmarkProvider.clear();
     }
 
     if (!m_sessionManager.isNull())
     {
+        kDebug() << "deleting session manager";
         delete m_sessionManager.data();
         m_sessionManager.clear();
     }
 
     if (!m_opensearchManager.isNull())
     {
+        kDebug() << "deleting opensearch manager";
         delete m_opensearchManager.data();
         m_opensearchManager.clear();
     }
 
     if (!m_iconManager.isNull())
     {
+        kDebug() << "deleting icon manager";
         delete m_iconManager.data();
         m_iconManager.clear();
     }
 
     if (!m_adblockManager.isNull())
     {
+        kDebug() << "deleting adblock manager";
         delete m_adblockManager.data();
         m_adblockManager.clear();
     }
@@ -135,12 +141,14 @@ Application::~Application()
     // TODO:
     // add a check to NOT close rekonq
     // until last download is finished
-
     if (!m_downloadManager.isNull())
     {
-        delete m_adblockManager.data();
-        m_adblockManager.clear();
+        kDebug() << "deleting download manager";
+        delete m_downloadManager.data();
+        m_downloadManager.clear();
     }
+
+    kDebug() << "Bye bye...";
 }
 
 
@@ -223,7 +231,7 @@ int Application::newInstance()
                 loadUrl(KUrl("about:home"), Rekonq::NewWindow);
                 break;
             case 2: // restore session
-                if (sessionManager()->restoreSession())
+                if (sessionManager()->restoreSessionFromScratch())
                 {
                     break;
                 }
@@ -251,6 +259,11 @@ int Application::newInstance()
         }
     }
 
+    if (!isRekonqCrashed)
+    {
+        sessionManager()->setSessionManagementEnabled(true);
+    }
+
     if (isFirstLoad)
     {
         // give me some time to do the other things..
@@ -275,7 +288,6 @@ void Application::postLaunch()
     setWindowIcon(KIcon("rekonq"));
 
     historyManager();
-    sessionManager()->setSessionManagementEnabled(true);
 
     // bookmarks loading
     connect(bookmarkProvider(), SIGNAL(openUrl(const KUrl&, const Rekonq::OpenType&)),
@@ -668,32 +680,48 @@ void Application::setPrivateBrowsingMode(bool b)
         QString text = i18n("<b>%1</b>"
                             "<p>rekonq will save your current tabs for when you'll stop private browsing the net.</p>", caption);
 
-        int button = KMessageBox::warningContinueCancel(mainWindow(), text, caption, KStandardGuiItem::cont(), KStandardGuiItem::cancel(), i18n("don't ask again"));
+        int button = KMessageBox::warningContinueCancel(mainWindow(),
+                     text, caption, KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
+                     i18n("don't ask again"));
         if (button != KMessageBox::Continue)
+        {
+            // The user canceled so we should uncheck the box
+            _privateBrowsingAction->setChecked(false);
             return;
+        }
 
+        sessionManager()->setSessionManagementEnabled(false);
         settings->setAttribute(QWebSettings::PrivateBrowsingEnabled, true);
         _privateBrowsingAction->setChecked(true);
 
+        loadUrl(KUrl("about:home"), Rekonq::NewWindow);
+
+        MainWindow *activeOne = m_mainWindows.at(0).data();
+
         Q_FOREACH(const QWeakPointer<MainWindow> &w, m_mainWindows)
         {
-            w.data()->close();
+            if (w.data() != activeOne)
+                w.data()->close();
         }
-        loadUrl(KUrl("about:home"), Rekonq::NewWindow);
     }
     else
     {
-        Q_FOREACH(const QWeakPointer<MainWindow> &w, m_mainWindows)
-        {
-            w.data()->close();
-        }
-
         settings->setAttribute(QWebSettings::PrivateBrowsingEnabled, false);
         _privateBrowsingAction->setChecked(false);
 
-        loadUrl(KUrl("about:blank"), Rekonq::NewWindow);
-        if (!sessionManager()->restoreSession())
+        int newWindows = sessionManager()->restoreSavedSession();
+        if (newWindows == 0)
+        {
             loadUrl(KUrl("about:home"), Rekonq::NewWindow);
+            newWindows++;
+        }
+
+        for (int i = newWindows; i < m_mainWindows.count(); ++i)
+        {
+            m_mainWindows.at(i).data()->close();
+        }
+
+        sessionManager()->setSessionManagementEnabled(true);
     }
 }
 
