@@ -48,9 +48,9 @@
 
 
 BookmarkOwner::BookmarkOwner(KBookmarkManager *manager, QObject *parent)
-        : QObject(parent)
-        , KBookmarkOwner()
-        , m_manager(manager)
+    : QObject(parent)
+    , KBookmarkOwner()
+    , m_manager(manager)
 {
 }
 
@@ -89,7 +89,14 @@ KAction* BookmarkOwner::createAction(const KBookmark &bookmark, const BookmarkAc
     case DELETE:
         return  createAction(i18n("Delete"), "edit-delete",
                              i18n("Delete the bookmark"), SLOT(deleteBookmark(const KBookmark &)), bookmark);
+    case SET_TOOLBAR_FOLDER:
+        return  createAction(i18n("Set as toolbar folder"), "bookmark-toolbar",
+                             "", SLOT(setToolBarFolder(KBookmark)), bookmark);
+    case UNSET_TOOLBAR_FOLDER:
+        return  createAction(i18n("Unset this folder as the toolbar folder"), "bookmark-toolbar",
+                             "", SLOT(unsetToolBarFolder()), bookmark);
     default:
+        ASSERT_NOT_REACHED();
         return 0;
     }
 }
@@ -152,7 +159,7 @@ void BookmarkOwner::openFolderinTabs(const KBookmarkGroup &bkGoup)
             return;
     }
 
-    Q_FOREACH(const KUrl &url, urlList)
+    Q_FOREACH(const KUrl & url, urlList)
     {
         emit openUrl(url, Rekonq::NewFocusedTab);
     }
@@ -332,6 +339,31 @@ bool BookmarkOwner::deleteBookmark(const KBookmark &bookmark)
 }
 
 
+void BookmarkOwner::setToolBarFolder(KBookmark bookmark)
+{
+    if (!bookmark.isGroup())
+        return;
+
+    unsetToolBarFolder();
+    bookmark.internalElement().setAttribute("toolbar", "yes");
+    bookmark.setIcon("bookmark-toolbar");
+
+    m_manager->emitChanged();
+}
+
+
+void BookmarkOwner::unsetToolBarFolder()
+{
+    KBookmarkGroup toolbar = m_manager->toolbar();
+    if (!toolbar.isNull())
+    {
+        toolbar.internalElement().setAttribute("toolbar", "no");
+        toolbar.setIcon("");
+    }
+    m_manager->emitChanged();
+}
+
+
 KAction* BookmarkOwner::createAction(const QString &text, const QString &icon,
                                      const QString &help, const char *slot,
                                      const KBookmark &bookmark)
@@ -347,8 +379,8 @@ KAction* BookmarkOwner::createAction(const QString &text, const QString &icon,
 
 
 CustomBookmarkAction::CustomBookmarkAction(const KBookmark &bookmark, const KIcon &icon, const QString &text, QObject *parent)
-        : KAction(icon, text, parent)
-        , m_bookmark(bookmark)
+    : KAction(icon, text, parent)
+    , m_bookmark(bookmark)
 {
     connect(this, SIGNAL(triggered()), this, SLOT(onActionTriggered()));
 }
