@@ -59,14 +59,14 @@
 #include <QtAlgorithms>
 
 
-static const unsigned int HISTORY_VERSION = 24;
+static const unsigned int HISTORY_VERSION = 25;
 
 
 HistoryManager::HistoryManager(QObject *parent)
-        : QWebHistoryInterface(parent)
-        , m_saveTimer(new AutoSaver(this))
-        , m_historyLimit(0)
-        , m_historyTreeModel(0)
+    : QWebHistoryInterface(parent)
+    , m_saveTimer(new AutoSaver(this))
+    , m_historyLimit(0)
+    , m_historyTreeModel(0)
 {
     connect(this, SIGNAL(entryAdded(const HistoryItem &)), m_saveTimer, SLOT(changeOccurred()));
     connect(this, SIGNAL(entryRemoved(const HistoryItem &)), m_saveTimer, SLOT(changeOccurred()));
@@ -123,7 +123,7 @@ void HistoryManager::addHistoryEntry(const QString &url)
         m_history.removeOne(item);
         emit entryRemoved(item);
 
-        item.dateTime = QDateTime::currentDateTime();
+        item.lastDateTimeVisit = QDateTime::currentDateTime();
         item.visitCount++;
     }
     else
@@ -172,7 +172,7 @@ void HistoryManager::checkForExpired()
 
     while (!m_history.isEmpty())
     {
-        QDateTime checkForExpired = m_history.last().dateTime;
+        QDateTime checkForExpired = m_history.last().lastDateTimeVisit;
         checkForExpired.setDate(checkForExpired.date().addDays(m_historyLimit));
         if (now.daysTo(checkForExpired) > 7)
         {
@@ -248,14 +248,14 @@ QList<HistoryItem> HistoryManager::find(const QString &text)
     QList<HistoryItem> list;
 
     QStringList urlKeys = m_historyFilterModel->keys();
-    Q_FOREACH(const QString &url, urlKeys)
+    Q_FOREACH(const QString & url, urlKeys)
     {
         int index = m_historyFilterModel->historyLocation(url);
         HistoryItem item = m_history.at(index);
 
         QStringList words = text.split(' ');
         bool matches = true;
-        foreach(const QString &word, words)
+        foreach(const QString & word, words)
         {
             if (!url.contains(word, Qt::CaseInsensitive)
                     && !item.title.contains(word, Qt::CaseInsensitive))
@@ -304,8 +304,6 @@ void HistoryManager::loadSettings()
         days = 365;
         break;
     case 5:
-        days = -1;
-        break;
     default:
         days = -1;
         break;
@@ -352,23 +350,33 @@ void HistoryManager::load()
         {
         case HISTORY_VERSION:   // default case
             stream >> item.url;
-            stream >> item.dateTime;
+            stream >> item.firstDateTimeVisit;
+            stream >> item.lastDateTimeVisit;
             stream >> item.title;
             stream >> item.visitCount;
             break;
 
-        case 23:    // this will be used to upgrade previous structure...
+        case 24:                // this was history structure for rekonq < 0.8
             stream >> item.url;
-            stream >> item.dateTime;
+            stream >> item.lastDateTimeVisit;
+            stream >> item.title;
+            stream >> item.visitCount;
+            item.firstDateTimeVisit = item.lastDateTimeVisit;
+            break;
+
+        case 23:                // this will be used to upgrade previous structure...
+            stream >> item.url;
+            stream >> item.lastDateTimeVisit;
             stream >> item.title;
             item.visitCount = 1;
+            item.firstDateTimeVisit = item.lastDateTimeVisit;
             break;
 
         default:
             continue;
         };
 
-        if (!item.dateTime.isValid())
+        if (!item.lastDateTimeVisit.isValid())
             continue;
 
         if (item == lastInsertedItem)
@@ -436,7 +444,7 @@ void HistoryManager::save()
     if (!open)
     {
         kDebug() << "Unable to open history file for saving"
-        << (saveAll ? tempFile.fileName() : historyFile.fileName());
+                 << (saveAll ? tempFile.fileName() : historyFile.fileName());
         return;
     }
 
@@ -446,7 +454,7 @@ void HistoryManager::save()
         QByteArray data;
         QDataStream stream(&data, QIODevice::WriteOnly);
         HistoryItem item = m_history.at(i);
-        stream << HISTORY_VERSION << item.url << item.dateTime << item.title << item.visitCount;
+        stream << HISTORY_VERSION << item.url << item.firstDateTimeVisit << item.lastDateTimeVisit << item.title << item.visitCount;
         out << data;
     }
     tempFile.close();
