@@ -59,8 +59,8 @@
 
 
 HistoryModel::HistoryModel(HistoryManager *history, QObject *parent)
-        : QAbstractTableModel(parent)
-        , m_historyManager(history)
+    : QAbstractTableModel(parent)
+    , m_historyManager(history)
 {
     Q_ASSERT(m_historyManager);
     connect(m_historyManager, SIGNAL(historyReset()), this, SLOT(historyReset()));
@@ -115,9 +115,11 @@ QVariant HistoryModel::data(const QModelIndex &index, int role) const
     switch (role)
     {
     case DateTimeRole:
-        return item.dateTime;
+        return item.lastDateTimeVisit;
     case DateRole:
-        return item.dateTime.date();
+        return item.lastDateTimeVisit.date();
+    case FirstDateTimeVisitRole:
+        return item.firstDateTimeVisit;
     case UrlRole:
         return QUrl(item.url);
     case Qt::UserRole:
@@ -152,7 +154,7 @@ QVariant HistoryModel::data(const QModelIndex &index, int role) const
         QString tooltip = "";
         if (!item.title.isEmpty())
             tooltip = item.title + '\n';
-        tooltip += item.dateTime.toString(Qt::SystemLocaleShortDate) + '\n' + item.url;
+        tooltip += item.lastDateTimeVisit.toString(Qt::SystemLocaleShortDate) + '\n' + item.url;
         return tooltip;
     }
     return QVariant();
@@ -188,12 +190,12 @@ bool HistoryModel::removeRows(int row, int count, const QModelIndex &parent)
 }
 
 
-// -------------------------------------------------------------------------------------------------------------------------------------------------
+// ------------------------------------------------------------------------------------------------------------------
 
 
 HistoryFilterModel::HistoryFilterModel(QAbstractItemModel *sourceModel, QObject *parent)
-        : QAbstractProxyModel(parent)
-        , m_loaded(false)
+    : QAbstractProxyModel(parent)
+    , m_loaded(false)
 {
     setSourceModel(sourceModel);
 }
@@ -354,18 +356,17 @@ void HistoryFilterModel::load() const
 
 void HistoryFilterModel::sourceRowsInserted(const QModelIndex &parent, int start, int end)
 {
-    //Q_ASSERT(start == end && start == 0);
     Q_UNUSED(end);
-    
-    if(start != 0)
+
+    if (start != 0)
     {
         kDebug() << "STARTING from a NON zero position...";
         return;
     }
-    
+
     if (!m_loaded)
         return;
-    
+
     QModelIndex idx = sourceModel()->index(start, 0, parent);
     QString url = idx.data(HistoryModel::UrlStringRole).toString();
     if (m_historyHash.contains(url))
@@ -418,11 +419,11 @@ bool HistoryFilterModel::removeRows(int row, int count, const QModelIndex &paren
 }
 
 
-// -------------------------------------------------------------------------------------------------------------------------------------------
+// ----------------------------------------------------------------------------------------------------------
 
 
 HistoryTreeModel::HistoryTreeModel(QAbstractItemModel *sourceModel, QObject *parent)
-        : QAbstractProxyModel(parent)
+    : QAbstractProxyModel(parent)
 {
     setSourceModel(sourceModel);
 }
@@ -436,7 +437,7 @@ QVariant HistoryTreeModel::headerData(int section, Qt::Orientation orientation,
 
 QVariant HistoryTreeModel::data(const QModelIndex &index, int role) const
 {
-    if ((role == Qt::EditRole || role == Qt::DisplayRole))
+    if (role == Qt::EditRole || role == Qt::DisplayRole)
     {
         int start = index.internalId();
         if (start == 0)
@@ -456,8 +457,10 @@ QVariant HistoryTreeModel::data(const QModelIndex &index, int role) const
             }
         }
     }
+
     if (role == Qt::DecorationRole && index.column() == 0 && !index.parent().isValid())
         return KIcon("view-history");
+
     if (role == HistoryModel::DateRole && index.column() == 0 && index.internalId() == 0)
     {
         int offset = sourceDateRow(index.row());
@@ -465,6 +468,13 @@ QVariant HistoryTreeModel::data(const QModelIndex &index, int role) const
         return idx.data(HistoryModel::DateRole);
     }
 
+    if (role == HistoryModel::FirstDateTimeVisitRole && index.column() == 0 && index.internalId() == 0)
+    {
+        int offset = sourceDateRow(index.row());
+        QModelIndex idx = sourceModel()->index(offset, 0);
+        return idx.data(HistoryModel::FirstDateTimeVisitRole);
+    }
+
     return QAbstractProxyModel::data(index, role);
 }
 
