@@ -62,6 +62,7 @@ QString temporaryUglyHackString = "";
 MainView::MainView(MainWindow *parent)
     : KTabWidget(parent)
     , m_widgetBar(new StackedUrlBar(this))
+    , m_originalWidthHint(0)
     , m_addTabButton(0)
     , m_currentTabIndex(0)
     , m_parentWindow(parent)
@@ -114,6 +115,7 @@ void MainView::postLaunch()
 
     m_addTabButton->setAutoRaise(true);
     m_addTabButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
+    m_originalWidthHint = sizeHint().width();
 }
 
 
@@ -186,13 +188,7 @@ void MainView::updateTabBar()
             ButtonInCorner = false;
         }
 
-        // detecting X position
-        int newPosX = tabBarWidth;
-        int tabWidthHint = tabBar()->tabSizeHint(0).width();
-        if (tabWidthHint < sizeHint().width() / 4)
-            newPosX = tabWidgetWidth - m_addTabButton->width();
-
-        m_addTabButton->move(newPosX, 0);
+        m_addTabButton->move(tabBarWidth, 0);
     }
 }
 
@@ -401,8 +397,6 @@ void MainView::closeOtherTabs(int index)
     {
         closeTab(i);
     }
-
-    updateTabBar();
 }
 
 
@@ -416,8 +410,6 @@ void MainView::cloneTab(int index)
     KUrl url = webTab(index)->url();
 
     rApp->loadUrl(url, Rekonq::NewTab);
-
-    updateTabBar();
 }
 
 
@@ -652,7 +644,7 @@ void MainView::openClosedTab()
     {
         WebView *view = rApp->mainWindow()->mainView()->newWebTab()->view();
         TabHistory history;
-        Q_FOREACH(TabHistory item, m_recentlyClosedTabs)
+        Q_FOREACH(const TabHistory & item, m_recentlyClosedTabs)
         {
             if (item.history == action->data().toByteArray())
             {
@@ -682,6 +674,7 @@ void MainView::loadFavorite(const int index)
         return;
     KUrl url = KUrl(urls.at(index - 1));
     rApp->loadUrl(url);
+    currentWebTab()->setFocus();
 }
 
 
