@@ -83,7 +83,6 @@ TabBar::TabBar(QWidget *parent)
 
     connect(this, SIGNAL(contextMenu(int, const QPoint &)), this, SLOT(contextMenu(int, const QPoint &)));
     connect(this, SIGNAL(emptyAreaContextMenu(const QPoint &)), this, SLOT(emptyAreaContextMenu(const QPoint &)));
-    connect(this, SIGNAL(tabMoved(int, int)), this, SLOT(tabMoved(int, int)));
 
     connect(m_animationMapper, SIGNAL(mapped(int)), this, SLOT(removeAnimation(int)));
     setGraphicsEffect(m_tabHighlightEffect);
@@ -98,8 +97,8 @@ QSize TabBar::tabSizeHint(int index) const
 
     int buttonSize = view->addTabButton()->size().width();
     int tabBarWidth = view->size().width() - buttonSize;
-    int baseWidth =  view->sizeHint().width() / baseWidthDivisor;
-    int minWidth =  view->sizeHint().width() / minWidthDivisor;
+    int baseWidth =  view->originalWidthHint() / baseWidthDivisor;
+    int minWidth =  view->originalWidthHint() / minWidthDivisor;
 
     int w;
     if (baseWidth * count() < tabBarWidth)
@@ -301,13 +300,6 @@ void TabBar::mousePressEvent(QMouseEvent *event)
 }
 
 
-void TabBar::tabMoved(int, int)
-{
-    MainView *mv = qobject_cast<MainView *>(parent());
-    QTimer::singleShot(200, mv, SIGNAL(tabsChanged()));
-}
-
-
 void TabBar::contextMenu(int tab, const QPoint &pos)
 {
     setupHistoryActions();
