@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2009 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2009-2011 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -63,12 +63,13 @@ public:
 
     KUrl url();
     virtual QString text();
-    
+
 public slots:
     virtual void nextItemSubChoice();
 
 signals:
     void itemClicked(ListItem *item, Qt::MouseButton, Qt::KeyboardModifiers);
+    void updateList();
 
 protected:
     virtual void paintEvent(QPaintEvent *event);
@@ -115,7 +116,7 @@ public:
 // -------------------------------------------------------------------------
 
 
-class TextLabel : public QLabel
+class REKONQ_TESTS_EXPORT TextLabel : public QLabel
 {
     Q_OBJECT
 
@@ -126,6 +127,17 @@ public:
     void setEngineText(const QString &engine, const QString &text);
 };
 
+// -------------------------------------------------------------------------
+
+
+class DescriptionLabel : public QLabel
+{
+    Q_OBJECT
+
+public:
+    explicit DescriptionLabel(const QString &text, QWidget *parent = 0);
+};
+
 
 // -------------------------------------------------------------------------
 
@@ -195,6 +207,22 @@ private:
 // -------------------------------------------------------------------------
 
 
+class VisualSuggestionListItem : public ListItem
+{
+    Q_OBJECT
+
+public:
+    VisualSuggestionListItem(const UrlSearchItem &item, const QString &text, QWidget *parent = 0);
+    QString text();
+
+private:
+    QString m_text;
+};
+
+
+// -------------------------------------------------------------------------
+
+
 class PreviewListItem : public ListItem
 {
     Q_OBJECT
@@ -216,6 +244,25 @@ public:
 };
 
 
+// -------------------------------------------------------------------------
+
+class ImageLabel : public QLabel
+{
+    Q_OBJECT
+
+public:
+    ImageLabel(const QString &url, int width, int height, QWidget *parent);
+
+private:
+    QString m_url;
+    QByteArray m_data;
+
+private slots:
+    void slotData(KIO::Job* job, const QByteArray& data);
+    void slotResult(KJob* job);
+};
+
+
 // -------------------------------------------------------------------------
 
 
