@@ -294,7 +294,7 @@ void UrlBar::keyPressEvent(QKeyEvent *event)
     {
         clearFocus();
         if (text() != rApp->mainWindow()->currentTab()->view()->url().toString()
-                && !rApp->mainWindow()->currentTab()->view()->url().toString().startsWith("about"))
+                && !rApp->mainWindow()->currentTab()->view()->url().toString().startsWith(QL1S("about")))
             setText(rApp->mainWindow()->currentTab()->view()->url().toString());
         event->accept();
     }
@@ -355,7 +355,7 @@ void UrlBar::loadFinished()
     if (!KStandardDirs::findExe("kget").isNull() && ReKonfig::kgetList())
     {
         IconButton *bt = addRightIcon(UrlBar::KGet);
-        connect(bt, SIGNAL(clicked(QPoint)), _tab->page(), SLOT(downloadAllContentsWithKGet(QPoint)));
+        connect(bt, SIGNAL(clicked(QPoint)), _tab->page(), SLOT(downloadAllContentsWithKGet()));
     }
 
     // show RSS
@@ -449,7 +449,8 @@ void UrlBar::activateSuggestions(bool b)
     {
         disconnect(this, SIGNAL(textChanged(const QString &)), this, SLOT(detectTypedString(const QString &)));
         removeEventFilter(_box.data());
-        _box.data()->deleteLater();
+        if (!_box.isNull())
+            _box.data()->deleteLater();
     }
 }
 
@@ -517,10 +518,20 @@ void UrlBar::contextMenuEvent(QContextMenuEvent* event)
 bool UrlBar::isValidURL(QString url)
 {
     bool isValid = false;
-    if (url.startsWith("http://") || url.startsWith("https://") || url.startsWith("ftp://"))
+    if (url.startsWith(QL1S("http://"))
+            || url.startsWith(QL1S("https://"))
+            || url.startsWith(QL1S("ftp://"))
+       )
         url = url.remove(QRegExp("(http|https|ftp)://"));
-    if (url.contains('.') && url.indexOf('.') > 0 && url.indexOf('.') < url.length() && !url.trimmed().contains(" ") && QUrl::fromUserInput(url).isValid())
+
+    if (url.contains(QL1C('.'))
+            && url.indexOf(QL1C('.')) > 0
+            && url.indexOf(QL1C('.')) < url.length()
+            && !url.trimmed().contains(QL1C(' '))
+            && QUrl::fromUserInput(url).isValid()
+       )
         isValid = true;
+
     return isValid;
 }
 
