@@ -180,7 +180,7 @@ static bool downloadResource(const KUrl& srcUrl, const KIO::MetaData& metaData =
     do
     {
         // follow bug:184202 fixes
-        destUrl = KFileDialog::getSaveFileName(KUrl(KGlobalSettings::downloadPath().append(fileName)), QString(), parent);
+        destUrl = KFileDialog::getSaveFileName(KUrl::fromPath(fileName), QString(), parent);
 
         if (destUrl.isEmpty())
             return false;
@@ -578,11 +578,10 @@ void WebPage::manageNetworkErrors(QNetworkReply *reply)
         return;
 
     case QNetworkReply::ContentAccessDenied:                 // access to remote content denied (similar to HTTP error 401)
-        kDebug() << "We (hopefully) are managing this through the adblock :)";
         break;
 
     case QNetworkReply::UnknownNetworkError:                 // unknown network-related error detected
-        kDebug() << "------------------ DO WE REALLY NEED THIS??? --------------------";
+        // FIXME: DO WE REALLY NEED THIS???
         _protHandler.postHandling(reply->request(), frame);
         return;
 
@@ -697,7 +696,7 @@ void WebPage::downloadUrl(const KUrl &url)
 }
 
 
-void WebPage::downloadAllContentsWithKGet(QPoint)
+void WebPage::downloadAllContentsWithKGet()
 {
     QSet<QString> contents;
     KUrl baseUrl(currentFrame()->url());
