@@ -36,8 +36,8 @@
 
 
 WebPluginFactory::WebPluginFactory(QObject *parent)
-        : KWebPluginFactory(parent)
-        , _loadClickToFlash(false)
+    : KWebPluginFactory(parent)
+    , _loadClickToFlash(false)
 {
     connect(this, SIGNAL(signalLoadClickToFlash(bool)), SLOT(setLoadClickToFlash(bool)));
 }
@@ -69,7 +69,7 @@ QObject *WebPluginFactory::create(const QString &mimeType,
         if (_loadClickToFlash)
         {
             emit signalLoadClickToFlash(false);
-            return 0; //KWebPluginFactory::create(mimeType, url, argumentNames, argumentValues);
+            return KWebPluginFactory::create(mimeType, url, argumentNames, argumentValues);
         }
         else
         {
@@ -83,7 +83,7 @@ QObject *WebPluginFactory::create(const QString &mimeType,
         return 0;
 
     default:
-        kDebug() << "oh oh.. this should NEVER happen..";
+        ASSERT_NOT_REACHED("oh oh.. this should NEVER happen..");
         break;
     }
 
